Function CreateSession
{
    $cred = Get-Credential
    $session = New-PSSession -ConfigurationName Microsoft.Exchange -ConnectionUri https://ps.outlook.com/powershell -Credential $cred -Authentication Basic -AllowRedirection
    $importresults = Import-PSSession $session
}

Function GrantUserAccessToMailbox($user, $mailbox)
{
    Get-Mailbox -identity $mailbox | Add-MailboxPermission -User:$user -AccessRights: ReadPermission -InheritanceType: All
}

Function Select-FileDialog
{
	param([string]$Title,[string]$Directory,[string]$Filter="All Files (*.*)|*.*")
	[System.Reflection.Assembly]::LoadWithPartialName("System.Windows.Forms") | Out-Null
	$objForm = New-Object System.Windows.Forms.OpenFileDialog
	$objForm.InitialDirectory = $Directory
	$objForm.Filter = $Filter
	$objForm.Title = $Title
    $objForm.ShowHelp = $true
	$Show = $objForm.ShowDialog()
	If ($Show -eq "OK")
	{
		Return $objForm.FileName
	}
	Else
	{
		Write-Error "Operation cancelled by user."
	}
}
$ErrorActionPreference = "Inquire"

Function Execute
{
    Param(
    [parameter(Mandatory=$true, HelpMessage="The user who will be given full access to the room mailboxes")]
    $User,
    [parameter(Mandatory=$true, HelpMessage="Room Mailbox Name")]    
    $Mailbox,
    [parameter(HelpMessage="CSV file containing a new line delimited list of rooms")]
    $CSV
    )
    
    if($Mailbox)
    {
        CreateSession
        GrantUserAccessToMailbox $User $Mailbox
    }
    else
    {
        $CSV = Select-FileDialog   
        CreateSession
        Import-Csv $CSV | ForEach-Object { GrantUserAccessToMailbox $User $_.rooms }
    }
    Write-Host "Press any key to continue ..."
    $x = $host.UI.RawUI.ReadKey("NoEcho,IncludeKeyDown")
}

Execute





